%
% Old testament
%
% Genesis 1:1-10, King James Version (KJV)
\BV(Gen 1:1 KJV) In the beginning God created the heaven and the earth.\null
\BV(Gen 1:1 KJV Alt) \dots \emph{God created the heaven and the earth}.\null
\BV(Gen 1:2 KJV) And the earth was without form, and void; and darkness was upon the face of the deep. And the Spirit of God moved upon the face of the waters.\null
\BV(Gen 1:3 KJV) And God said, Let there be light: and there was light.\null
\BV(Gen 1:4 KJV) And God saw the light, that it was good: and God divided the light from the darkness.\null
\BV(Gen 1:5 KJV) And God called the light Day, and the darkness he called Night. And the evening and the morning were the first day.\null
\BV(Gen 1:6 KJV) And God said, Let there be a firmament in the midst of the waters, and let it divide the waters from the waters.\null
\BV(Gen 1:7 KJV) And God made the firmament, and divided the waters which were under the firmament from the waters which were above the firmament: and it was so.\null
\BV(Gen 1:8 KJV) And God called the firmament Heaven. And the evening and the morning were the second day.\null
\BV(Gen 1:9 KJV) And God said, Let the waters under the heaven be gathered together unto one place, and let the dry land appear: and it was so.\null
\BV(Gen 1:10 KJV) And God called the dry land Earth; and the gathering together of the waters called he Seas: and God saw that it was good.\null
% Genesis 1:1-10, International Standard Version (ISV)
\BV(Gen 1:1 ISV) In the beginning, God created the universe.\null
\BV(Gen 1:1 ISV Alt) \emph{In the beginning}, God created the universe.\null
\BV(Gen 1:2 ISV) When the earth was as yet unformed and desolate, with the surface of the ocean depths shrouded in darkness, and while the Spirit of God was hovering over the surface of the waters,\null
\BV(Gen 1:3 ISV) God said, "Let there be light!" So there was light.\null
\BV(Gen 1:4 ISV) God saw that the light was beautiful. He separated the light from the darkness,\null
\BV(Gen 1:5 ISV) calling the light "day," and the darkness "night." The twilight and the dawn were day one.\null
\BV(Gen 1:6 ISV) Then God said, "Let there be a canopy between bodies of water, separating bodies of water from bodies of water!"\null
\BV(Gen 1:7 ISV) So God made a canopy that separated the water beneath the canopy from the water above it. And that is what happened:\null
\BV(Gen 1:8 ISV) God called the canopy "sky." The twilight and the dawn were the second day.\null
\BV(Gen 1:9 ISV) Then God said, "Let the water beneath the sky come together into one area, and let dry ground appear!" And that is what happened:\null
\BV(Gen 1:10 ISV) God called the dry ground "land," and he called the water that had come together "oceans." And God saw how good it was.\null
% Genesis 1:1-2, Young's Literal Translation (YLT)
\BV(Gen 1:1 YLT) In the beginning of God's preparing the heavens and the earth--\null
\BV(Gen 1:2 YLT) the earth hath existed waste and void, and darkness is on the face of the deep, and the Spirit of God fluttering on the face of the waters,\null
% Genesis 1:1-5, American Standard Version (ASV)
\BV(Gen 1:1 ASV) In the beginning God created the heavens and the earth.\null
\BV(Gen 1:2 ASV) And the earth was waste and void; and darkness was upon the face of the deep: and the Spirit of God moved upon the face of the waters.\null
\BV(Gen 1:3 ASV) And God said, Let there be light: and there was light.\null
\BV(Gen 1:4 ASV) And God saw the light, that it was good: and God divided the light from the darkness.\null
\BV(Gen 1:5 ASV) And God called the light Day, and the darkness he called Night. And there was evening and there was morning, one day.\null
% I Kings 1:1-5, KJV
\BV(1Ki 1:1 KJV) Now king David was old and stricken in years; and they covered him with clothes, but he gat no heat.\null
\BV(1Ki 1:2 KJV) Wherefore his servants said unto him, Let there be sought for my lord the king a young virgin: and let her stand before the king, and let her cherish him, and let her lie in thy bosom, that my lord the king may get heat.\null
\BV(1Ki 1:3 KJV) So they sought for a fair damsel throughout all the coasts of Israel, and found Abishag a Shunammite, and brought her to the king.\null
\BV(1Ki 1:4 KJV) And the damsel was very fair, and cherished the king, and ministered to him: but the king knew her not.\null
\BV(1Ki 1:5 KJV) Then Adonijah the son of Haggith exalted himself, saying, I will be king: and he prepared him chariots and horsemen, and fifty men to run before him.\null
% I Kings 1L1-5, ISV
\BV(1Ki 1:1 ISV) When David had grown very old, they covered him with blankets, but he could not keep warm,\null
\BV(1Ki 1:1 ISV Alt) When David had grown \emph{very old}, they covered him with blankets, but he could not keep warm,\null
\BV(1Ki 1:2 ISV) so his servants suggested to him, "Let's look for a young virgin woman to take care of you, your majesty. She will be of use to you if you have her lie down near you so that your majesty may keep warm."\null
\BV(1Ki 1:3 ISV) So they conducted a search throughout the territory of Israel for a beautiful young woman, and Abishag the Shunammite was located and brought to the king.\null
\BV(1Ki 1:4 ISV) The young woman was absolutely beautiful. She served the king and was very useful to him. The king was not sexually involved with her.\null
\BV(1Ki 1:5 ISV) Meanwhile, about this time Haggith's son Adonijah began to seek a reputation for himself and decided, "I'm going to be king!" So he prepared chariots, cavalry, and 50 soldiers to serve as a security detail to guard him.\null
%
% New testament
%
% Colassians 1:6, KJV
\BV(Col 1:6 KJV) that has come to you. Just as it is bearing fruit and spreading all over the world, so it has been doing among you from the day you heard it and came to know the grace of God in truth.\null
\BV(Col 1:6 KJV Alt) \dots Just as it is bearing fruit and spreading all over the world, so it has been doing among you from the day you heard it and came to know the grace of God in truth.\null
% Matthew 2:1-10, KJV
\BV(Mat 2:1 KJV) Now when Jesus was born in Bethlehem of Judaea in the days of Herod the king, behold, there came wise men from the east to Jerusalem,\null
\BV(Mat 2:2 KJV) Saying, Where is he that is born King of the Jews? for we have seen his star in the east, and are come to worship him.\null
\BV(Mat 2:3 KJV) When Herod the king had heard these things, he was troubled, and all Jerusalem with him.\null
\BV(Mat 2:4 KJV) And when he had gathered all the chief priests and scribes of the people together, he demanded of them where Christ should be born.\null
\BV(Mat 2:5 KJV) And they said unto him, In Bethlehem of Judaea: for thus it is written by the prophet,\null
\BV(Mat 2:6 KJV) And thou Bethlehem, in the land of Juda, art not the least among the princes of Juda: for out of thee shall come a Governor, that shall rule my people Israel.\null
\BV(Mat 2:7 KJV) Then Herod, when he had privily called the wise men, enquired of them diligently what time the star appeared.\null
\BV(Mat 2:8 KJV) And he sent them to Bethlehem, and said, Go and search diligently for the young child; and when ye have found him, bring me word again, that I may come and worship him also.\null
\BV(Mat 2:9 KJV) When they had heard the king, they departed; and, lo, the star, which they saw in the east, went before them, till it came and stood over where the young child was.\null
\BV(Mat 2:10 KJV) When they saw the star, they rejoiced with exceeding great joy.\null
% Romans 1:1 King James version w/Strongs Numbers (KJV+)
\BV(Rom 1:1 KJV+) Paul,\G{3972} a servant\G{1401} of Jesus\G{2424} Christ,\G{5547} called\G{2822} to be an apostle,\G{652} separated\G{873} unto\G{1519} the gospel\G{2098} of God,\G{2316}\null
% I Corinthians 1:1-5 KJV
\BV(1Co 1:1 KJV) Paul, called to be an apostle of Jesus Christ through the will of God, and Sosthenes our brother,\null
\BV(1Co 1:2 KJV) Unto the church of God which is at Corinth, to them that are sanctified in Christ Jesus, called to be saints, with all that in every place call upon the name of Jesus Christ our Lord, both theirs and ours:\null
\BV(1Co 1:3 KJV) Grace be unto you, and peace, from God our Father, and from the Lord Jesus Christ.\null
\BV(1Co 1:4 KJV) I thank my God always on your behalf, for the grace of God which is given you by Jesus Christ;\null
\BV(1Co 1:5 KJV) That in every thing ye are enriched by him, in all utterance, and in all knowledge;\null
